# Lolicon

![CI](https://github.com/hentai-chan/lolicon/workflows/CI/badge.svg)

![CodeQL](https://github.com/hentai-chan/lolicon/workflows/CodeQL/badge.svg)

[![CodeFactor](https://www.codefactor.io/repository/github/hentai-chan/lolicon/badge?s=73446cb8092f75fb1c893e480473680065734a05)](https://www.codefactor.io/repository/github/hentai-chan/lolicon)

[![codecov](https://codecov.io/gh/hentai-chan/lolicon/branch/master/graph/badge.svg?token=7KX4DQSZBV)](https://codecov.io/gh/hentai-chan/lolicon)

![Python](https://img.shields.io/badge/Python-%203.8%20%7C%203.9-blue)

```bash
Development Status :: 1 - Planning
```
